#
# spec file for package apfel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname libAPFEL0
%define pypackage python-%{name}

Name:           apfel
Version:        2.7.0
Release:        3.2
Summary:        A Probability Distribution Function Evolution Library
License:        GPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://apfel.hepforge.org/
Source:         https://github.com/scarrazza/%{name}/archive/%{version}.tar.gz
BuildRequires:  LHAPDF-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libqt4-devel
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64

%description
APFEL is a library to perform the combined QCD+QED DGLAP 
evolution of parton distributions.

%package -n %{soname}
Summary:        A Probability Distribution Function Evolution Library
Group:          System/Libraries

%description -n %{soname}
APFEL is a library to perform the combined QCD+QED DGLAP 
evolution of parton distributions.

This package provides the shared libraries for %{name}.

%package devel
Summary:        Development files for Apfel, a PDF Evolution Library
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       LHAPDF-devel

%description devel
APFEL is a library to perform the combined QCD+QED DGLAP 
evolution of parton distributions.

This package provides the source files required to develop
applications with %{name}.

%package -n %{pypackage}
Summary:        A PDF Evolution Library
Group:          Development/Languages/Python

%description -n %{pypackage}
APFEL is a library to perform the combined QCD+QED DGLAP 
evolution of parton distributions.

This package provides the shared libraries for %{name}.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

# REMOVE libtool ARCHIVES
rm %{buildroot}%{_libdir}/*.la

# REMOVE README FROM A NON-STD LOCATION, INSTALL IT USING %%doc INSTEAD
rm -fr %{buildroot}%{_datadir}/doc/apfel

%post   -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/APFEL/
%doc AUTHORS ChangeLog NEWS README COPYING
%{_bindir}/CheckAPFEL
%{_bindir}/%{name}-config
%{_libdir}/*.so

%files -n %{pypackage}
%defattr(-,root,root)
%{_bindir}/%{name}
%{_bindir}/ListFunctions
%{python_sitearch}/%{name}.py
# COMPILED OBJECT FILE CONTAINS BUILDROOT
%exclude %{python_sitearch}/%{name}.pyc
%{python_sitearch}/_%{name}.so
%{python_sitearch}/APFEL-*py%{py_ver}.egg-info
%dir %{_datadir}/apfel
%{_datadir}/%{name}/gen_info.py
%{_datadir}/%{name}/*.info

%changelog
* Mon Feb 15 2016 jengelh@inai.de
- Expand PDF acronym in summaries
- Drop author list from description, openSUSE does not do this
  since many many months.
* Tue Feb  2 2016 badshah400@gmail.com
- Update to version 2.7.0:
  + Implementation of the polarized evolution up to NNLO.
  + Implementation of the LO contribution to intrinsic charm in
    FONLL.
  + Possibility to perform dynamical factorization/renormalization
    scale variations.
  + New functions to feed higher order EW corrections.
  + Reduction of the memory footprint.
  + Speed up of the initialization phase.
  + Minor improvements and bug fixings.
- Changes from version 2.6.0:
  + Implementation of the factorization and renormalization scale
    variation for the DIS structure functions.
  + Implementation of a faster solution for the QCD+QED unified
    solution of the DGLAP equation.
  + Improving the production of the LHAPDF grids.
  + Improving the accuracy of the truncated solution of the DGLAP
    equation (from 3- to 5-point derivative).
  + Colorful banner.
  + Minor improvements.
- Apfelgui is deprecated, drop all supporting files:
  +  apfelgui.changes.
  +  pre_checkin.sh.
  +  apfelgui.spec.
  +  apfelgui.spec.in.
  +  README.
* Thu Jul  9 2015 badshah400@gmail.com
- Update to version 2.5.2:
  + Implementation of truncated PDF evolution.
  + libAPFELevol: a light version of APFEL with just evolution.
  + general code improvements.
  + Fixed bugs:
  - Fixed bug in the computation of the SIA cross-sections.
  - Fixed xmax and xmin tolerance.
- Changes from previous versions 2.3.4 through 2.4.0:
  + See https://github.com/scarrazza/apfel/releases.
* Fri Mar 20 2015 badshah400@gmail.com
- Update to version 2.3.3:
  + Functions for the production of FK tables.
  + Updated format of the output LHAPDF grids.
  + Implementation of semi-inclusive e^+e^- annihilation structure
    functions,
  + Added flag to the apfel-config script to list the APFEL
    functions.
- Changes from previous versions:
  + Long list of changes since previous packaged version, see NEWS
    file.
- Packaging changes: Use LHAPDF 6.x (instead of 5.x) for building,
  since apfel is now LHAPDFv6 compatible.
- Since version 2.3.0, building on 32-bit architectures is
  unsupported by upstream.
* Thu May  1 2014 badshah400@gmail.com
- apfelgui: Requires(post) and Requires(postun) should be on
  desktop-file-utils (for %%desktop_database_post(un) scriptlets)
  rather than on update-desktop-files.
* Tue Apr 29 2014 badshah400@gmail.com
- apfel-devel should have a "Requires:" on lhapdf-devel <= 5.9.1.
* Sat Apr 19 2014 badshah400@gmail.com
- Build and install hicolor icons (introduces a BuildRequires on
  hicolor-icon-theme) and desktop menu entry.
* Sun Apr 13 2014 badshah400@gmail.com
- Initial package (version 2.0.1).
